==> portal-transparencia-1.57.0.zip: BOOT-INF/classes/db/sql/contab/liquidacao-pagar.sql <==
SELECT row_number() OVER (PARTITION BY XX.FONTERECURSO ORDER BY XX.FONTERECURSO, XX.DATA, XX.EMPENHO, XX.EXERCICIO) AS ORDEMFONTERECURSO, XX.*
  FROM (
SELECT FR.FONTERECURSO || ' - ' || FR.DESCRICAO AS FONTERECURSO,
       L.DATA,
       O.VENCIMENTO DATAVENCIMENTO,
       P.DATA DATAPAGAMENTO,
       L.EXERCICIO AS EXERCICIOLIQUIDACAO,
       L.NOLIQUIDACAO,
       E.EMPENHO || '/' || E.EXERCICIO AS EMPENHOEXERCICIO,
       E.ENTIDADE,
       E.EXERCICIO,
       E.EMPENHO,
       E.UNIDADEORCAMENTARIA,
       TL.DESCRICAO AS TIPOLICITACAO,
       E.NOLICITACAO || '/' || E.ANOLICITACAO AS LICITACAO,
       F.CNPJ || ' - ' || F.NOME AS FORNECEDOR,
       OL.NOORDEM,
       OL.SEQUENCIA,
       L.VALOR AS VALOR,
       (L.VALOR - L.VALORRETENCOES -
       (SELECT COALESCE(SUM(EL.VALOR), 0)
          FROM ESTORNOLIQUIDACAO EL
         WHERE EL.ENTIDADE = L.ENTIDADE
           AND EL.EXERCICIOLIQ = L.EXERCICIO
           AND EL.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND EL.ANODOCORIGEM = L.ANODOCORIGEM
           AND EL.NODOCORIGEM = L.NODOCORIGEM
           AND EL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND EL.NOLIQUIDACAO = L.NOLIQUIDACAO) -
       (SELECT COALESCE(SUM(CR.VALOR), 0)
          FROM CANCELAMENTORESTOS CR
         WHERE CR.ENTIDADE = L.ENTIDADE
           AND CR.EXERCICIO = L.ANODOCORIGEM
           AND CR.EMPENHO = L.NODOCORIGEM
           AND CR.UNIDADEORCAMENTARIA = L.UNIDADEDOCORIGEM) -
       (SELECT COALESCE(SUM(OPL.VALOR), 0)
          FROM ORDEMPAGAMENTO_LIQUIDACAO OPL
          JOIN ORDEMPAGAMENTO OP 
            ON OP.CANCELADO = 'P'
           AND OP.ENTIDADE  = OPL.ENTIDADE
           AND OP.NOORDEM   = OPL.NOORDEM
           AND OP.EXERCICIO = OPL.EXERCICIO
         WHERE OPL.ENTIDADE = L.ENTIDADE
           AND OPL.EXERCICIOLIQ  = L.EXERCICIO
           AND OPL.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND OPL.ANODOCORIGEM  = L.ANODOCORIGEM
           AND OPL.NODOCORIGEM   = L.NODOCORIGEM
           AND OPL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND OPL.NOLIQUIDACAO = L.NOLIQUIDACAO) -
       (SELECT COALESCE(SUM(R.VALOR), 0)
          FROM ORDEMPAGAMENTO_RETENCAO R
          JOIN ORDEMPAGAMENTO OP
            ON OP.CANCELADO = 'P'
           AND OP.ENTIDADE  = R.ENTIDADE
           AND OP.NOORDEM   = R.NOORDEM
           AND OP.EXERCICIO = R.EXERCICIO
         WHERE R.ENTIDADE   = L.ENTIDADE
           AND R.EXERCICIOLIQ  = L.EXERCICIO
           AND R.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND R.ANODOCORIGEM  = L.ANODOCORIGEM
           AND R.NODOCORIGEM   = L.NODOCORIGEM
           AND R.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND R.NOLIQUIDACAO  = L.NOLIQUIDACAO)) AS SALDO
  FROM LIQUIDACAO L
  LEFT JOIN EMPENHO E 
    ON L.ENTIDADE = E.ENTIDADE
   AND L.ANODOCORIGEM = E.EXERCICIO
   AND L.NODOCORIGEM = E.EMPENHO
   AND L.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA
  LEFT JOIN FONTERECURSO FR 
    ON E.FONTERECURSO = FR.FONTERECURSO
  LEFT JOIN TIPOSLICITACAO TL 
    ON E.TIPOLICITACAO = TL.TIPOLICITACAO
  LEFT JOIN FORNECEDOR F 
    ON E.FORNECEDOR = F.FORNECEDOR
  LEFT JOIN ORDEMPAGAMENTO_LIQUIDACAO OL
    ON OL.ENTIDADE = L.ENTIDADE
   AND OL.EXERCICIO = L.EXERCICIO
   AND OL.NOLIQUIDACAO = L.NOLIQUIDACAO
   AND OL.TIPODOCORIGEM = L.TIPODOCORIGEM
   AND OL.ANODOCORIGEM = L.ANODOCORIGEM
   AND OL.NODOCORIGEM = L.NODOCORIGEM
   AND OL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
  LEFT JOIN ORDEMPAGAMENTO O
    ON O.ENTIDADE = OL.ENTIDADE
   AND O.EXERCICIO = OL.EXERCICIO
   AND O.NOORDEM = OL.NOORDEM
  LEFT JOIN PAGAMENTO P
    ON P.ENTIDADE = O.ENTIDADE
   AND P.ANOORDEMPAGAMENTO = O.EXERCICIO
   AND P.NOORDEMPAGAMENTO = O.NOORDEM
  $[FILTRO]
       ) XX 
  $[WHERE]
  (((XX.EXERCICIOLIQUIDACAO <= 2013) AND 
        (NOT EXISTS (SELECT C.EMPENHO
                       FROM CANCELAMENTORESTOS C
                      WHERE C.ENTIDADE   = XX.ENTIDADE
                        AND C.EXERCICIO  = XX.EXERCICIO
                        AND C.EMPENHO    = XX.EMPENHO
                        AND C.UNIDADEORCAMENTARIA = XX.UNIDADEORCAMENTARIA
                        AND C.FLAGAPROCESSAR = 'N'))) OR (XX.EXERCICIOLIQUIDACAO > 2013))
   AND EXISTS (SELECT X.ENTIDADE, X.EXERCICIO, X.EMPENHO, X.UNIDADEORCAMENTARIA
                 FROM (SELECT E.ENTIDADE,
                              E.EXERCICIO,
                              E.EMPENHO,
                              E.UNIDADEORCAMENTARIA,
                              SUM(FE.VALOR) AS EMPENHADO,
                              SUM(FE.VALORANULACOES - FE.VALORESTANULACOES) AS ANULADO,
                              SUM(FE.VALORRETENCOES) AS RETIDO,
                              SUM(FE.VALORPAGAMENTO - FE.VALORESTPAGAMENTO) AS PAGO
                         FROM EMPENHO E
                         LEFT OUTER JOIN FICHAEMPENHO FE 
                           ON E.ENTIDADE  = FE.ENTIDADE
                          AND E.EXERCICIO = FE.EXERCICIO
                          AND E.EMPENHO   = FE.EMPENHO
                          AND E.UNIDADEORCAMENTARIA = FE.UNIDADEORCAMENTARIA
                        WHERE E.CONTABILIZADO = 'S'
                        GROUP BY E.ENTIDADE, E.EXERCICIO, E.EMPENHO, E.UNIDADEORCAMENTARIA) X
                WHERE (X.EMPENHADO - X.ANULADO - X.RETIDO - X.PAGO) >= 0.01
                  AND X.ENTIDADE  = XX.ENTIDADE
                  AND X.EXERCICIO = XX.EXERCICIO
                  AND X.EMPENHO   = XX.EMPENHO
                  AND X.UNIDADEORCAMENTARIA = XX.UNIDADEORCAMENTARIA)

==> portal-transparencia-1.69.5.zip: BOOT-INF/classes/db/sql/contab/liquidacao-pagar.sql <==
SELECT row_number() OVER (PARTITION BY XX.FONTERECURSO ORDER BY XX.FONTERECURSO, XX.DATA, XX.EMPENHO, XX.EXERCICIO) AS ORDEMFONTERECURSO, XX.*
  FROM (
SELECT FR.FONTERECURSO || ' - ' || FR.DESCRICAO AS FONTERECURSO,
       L.DATA,
       O.VENCIMENTO DATAVENCIMENTO,
       P.DATA DATAPAGAMENTO,
       L.EXERCICIO AS EXERCICIOLIQUIDACAO,
       L.NOLIQUIDACAO,
       E.EMPENHO || '/' || E.EXERCICIO AS EMPENHOEXERCICIO,
       E.ENTIDADE,
       E.EXERCICIO,
       E.EMPENHO,
       E.UNIDADEORCAMENTARIA,
       TL.DESCRICAO AS TIPOLICITACAO,
       E.NOLICITACAO || '/' || E.ANOLICITACAO AS LICITACAO,
       F.CNPJ || ' - ' || F.NOME AS FORNECEDOR,
       OL.NOORDEM,
       OL.SEQUENCIA,
       L.VALOR AS VALOR,
       (L.VALOR - L.VALORRETENCOES -
       (SELECT COALESCE(SUM(EL.VALOR), 0)
          FROM ESTORNOLIQUIDACAO EL
         WHERE EL.ENTIDADE = L.ENTIDADE
           AND EL.EXERCICIOLIQ = L.EXERCICIO
           AND EL.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND EL.ANODOCORIGEM = L.ANODOCORIGEM
           AND EL.NODOCORIGEM = L.NODOCORIGEM
           AND EL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND EL.NOLIQUIDACAO = L.NOLIQUIDACAO) -
       (SELECT COALESCE(SUM(CR.VALOR), 0)
          FROM CANCELAMENTORESTOS CR
         WHERE CR.ENTIDADE = L.ENTIDADE
           AND CR.EXERCICIO = L.ANODOCORIGEM
           AND CR.EMPENHO = L.NODOCORIGEM
           AND CR.UNIDADEORCAMENTARIA = L.UNIDADEDOCORIGEM) -
       (SELECT COALESCE(SUM(OPL.VALOR), 0)
          FROM ORDEMPAGAMENTO_LIQUIDACAO OPL
          JOIN ORDEMPAGAMENTO OP 
            ON OP.CANCELADO = 'P'
           AND OP.ENTIDADE  = OPL.ENTIDADE
           AND OP.NOORDEM   = OPL.NOORDEM
           AND OP.EXERCICIO = OPL.EXERCICIO
         WHERE OPL.ENTIDADE = L.ENTIDADE
           AND OPL.EXERCICIOLIQ  = L.EXERCICIO
           AND OPL.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND OPL.ANODOCORIGEM  = L.ANODOCORIGEM
           AND OPL.NODOCORIGEM   = L.NODOCORIGEM
           AND OPL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND OPL.NOLIQUIDACAO = L.NOLIQUIDACAO) -
       (SELECT COALESCE(SUM(R.VALOR), 0)
          FROM ORDEMPAGAMENTO_RETENCAO R
          JOIN ORDEMPAGAMENTO OP
            ON OP.CANCELADO = 'P'
           AND OP.ENTIDADE  = R.ENTIDADE
           AND OP.NOORDEM   = R.NOORDEM
           AND OP.EXERCICIO = R.EXERCICIO
         WHERE R.ENTIDADE   = L.ENTIDADE
           AND R.EXERCICIOLIQ  = L.EXERCICIO
           AND R.TIPODOCORIGEM = L.TIPODOCORIGEM
           AND R.ANODOCORIGEM  = L.ANODOCORIGEM
           AND R.NODOCORIGEM   = L.NODOCORIGEM
           AND R.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
           AND R.NOLIQUIDACAO  = L.NOLIQUIDACAO)) AS SALDO,
		   O.CANCELADO
  FROM LIQUIDACAO L
  LEFT JOIN EMPENHO E 
    ON L.ENTIDADE = E.ENTIDADE
   AND L.ANODOCORIGEM = E.EXERCICIO
   AND L.NODOCORIGEM = E.EMPENHO
   AND L.UNIDADEDOCORIGEM = E.UNIDADEORCAMENTARIA
  LEFT JOIN FONTERECURSO FR 
    ON E.FONTERECURSO = FR.FONTERECURSO
  LEFT JOIN TIPOSLICITACAO TL 
    ON E.TIPOLICITACAO = TL.TIPOLICITACAO
  LEFT JOIN FORNECEDOR F 
    ON E.FORNECEDOR = F.FORNECEDOR
  LEFT JOIN ORDEMPAGAMENTO_LIQUIDACAO OL
    ON OL.ENTIDADE = L.ENTIDADE
   AND OL.EXERCICIO = L.EXERCICIO
   AND OL.NOLIQUIDACAO = L.NOLIQUIDACAO
   AND OL.TIPODOCORIGEM = L.TIPODOCORIGEM
   AND OL.ANODOCORIGEM = L.ANODOCORIGEM
   AND OL.NODOCORIGEM = L.NODOCORIGEM
   AND OL.UNIDADEDOCORIGEM = L.UNIDADEDOCORIGEM
  LEFT JOIN ORDEMPAGAMENTO O
    ON O.ENTIDADE = OL.ENTIDADE
   AND O.EXERCICIO = OL.EXERCICIO
   AND O.NOORDEM = OL.NOORDEM
  LEFT JOIN PAGAMENTO P
    ON P.ENTIDADE = O.ENTIDADE
   AND P.ANOORDEMPAGAMENTO = O.EXERCICIO
   AND P.NOORDEMPAGAMENTO = O.NOORDEM
  $[FILTRO]
       ) XX 
  $[WHERE]
  (((XX.EXERCICIOLIQUIDACAO <= 2013) AND 
        (NOT EXISTS (SELECT C.EMPENHO
                       FROM CANCELAMENTORESTOS C
                      WHERE C.ENTIDADE   = XX.ENTIDADE
                        AND C.EXERCICIO  = XX.EXERCICIO
                        AND C.EMPENHO    = XX.EMPENHO
                        AND C.UNIDADEORCAMENTARIA = XX.UNIDADEORCAMENTARIA
                        AND C.FLAGAPROCESSAR = 'N'))) OR (XX.EXERCICIOLIQUIDACAO > 2013))
   AND EXISTS (SELECT X.ENTIDADE, X.EXERCICIO, X.EMPENHO, X.UNIDADEORCAMENTARIA
                 FROM (SELECT E.ENTIDADE,
                              E.EXERCICIO,
                              E.EMPENHO,
                              E.UNIDADEORCAMENTARIA,
                              SUM(FE.VALOR) AS EMPENHADO,
                              SUM(FE.VALORANULACOES - FE.VALORESTANULACOES) AS ANULADO,
                              SUM(FE.VALORRETENCOES) AS RETIDO,
                              SUM(FE.VALORPAGAMENTO - FE.VALORESTPAGAMENTO) AS PAGO
                         FROM EMPENHO E
                         LEFT OUTER JOIN FICHAEMPENHO FE 
                           ON E.ENTIDADE  = FE.ENTIDADE
                          AND E.EXERCICIO = FE.EXERCICIO
                          AND E.EMPENHO   = FE.EMPENHO
                          AND E.UNIDADEORCAMENTARIA = FE.UNIDADEORCAMENTARIA
                        WHERE E.CONTABILIZADO = 'S'
                        GROUP BY E.ENTIDADE, E.EXERCICIO, E.EMPENHO, E.UNIDADEORCAMENTARIA) X
                WHERE (X.EMPENHADO - X.ANULADO - X.RETIDO - X.PAGO) >= 0.01
                  AND X.ENTIDADE  = XX.ENTIDADE
                  AND X.EXERCICIO = XX.EXERCICIO
                  AND X.EMPENHO   = XX.EMPENHO
                  AND X.UNIDADEORCAMENTARIA = XX.UNIDADEORCAMENTARIA)
